@@ -50,11 +50,11 @@ var LibraryGLUT = {
       if (GLUT.buttons == 0 && event.target == Module["canvas"] && GLUT.passiveMotionFunc) {
         event.preventDefault();
         GLUT.saveModifiers(event);
-        Runtime.dynCall('vii', GLUT.passiveMotionFunc, [lastX, lastY]);
+        Module['dynCall_vii'](GLUT.passiveMotionFunc, lastX, lastY);
       } else if (GLUT.buttons != 0 && GLUT.motionFunc) {
         event.preventDefault();
         GLUT.saveModifiers(event);
-        Runtime.dynCall('vii', GLUT.motionFunc, [lastX, lastY]);
+        Module['dynCall_vii'](GLUT.motionFunc, lastX, lastY);
       }
     },
 
@@ -162,7 +162,7 @@ var LibraryGLUT = {
           if( GLUT.specialFunc ) {
             event.preventDefault();
             GLUT.saveModifiers(event);
-            Runtime.dynCall('viii', GLUT.specialFunc, [key, Browser.mouseX, Browser.mouseY]);
+            Module['dynCall_viii'](GLUT.specialFunc, key, Browser.mouseX, Browser.mouseY);
           }
         }
         else
@@ -171,7 +171,7 @@ var LibraryGLUT = {
           if( key !== null && GLUT.keyboardFunc ) {
             event.preventDefault();
             GLUT.saveModifiers(event);
-            Runtime.dynCall('viii', GLUT.keyboardFunc, [key, Browser.mouseX, Browser.mouseY]);
+            Module['dynCall_viii'](GLUT.keyboardFunc, key, Browser.mouseX, Browser.mouseY);
           }
         }
       }
@@ -184,7 +184,7 @@ var LibraryGLUT = {
           if(GLUT.specialUpFunc) {
             event.preventDefault ();
             GLUT.saveModifiers(event);
-            Runtime.dynCall('viii', GLUT.specialUpFunc, [key, Browser.mouseX, Browser.mouseY]);
+            Module['dynCall_viii'](GLUT.specialUpFunc, key, Browser.mouseX, Browser.mouseY);
           }
         }
         else
@@ -193,7 +193,7 @@ var LibraryGLUT = {
           if( key !== null && GLUT.keyboardUpFunc ) {
             event.preventDefault ();
             GLUT.saveModifiers(event);
-            Runtime.dynCall('viii', GLUT.keyboardUpFunc, [key, Browser.mouseX, Browser.mouseY]);
+            Module['dynCall_viii'](GLUT.keyboardUpFunc, key, Browser.mouseX, Browser.mouseY);
           }
         }
       }
@@ -236,7 +236,7 @@ var LibraryGLUT = {
         } catch (e) {}
         event.preventDefault();
         GLUT.saveModifiers(event);
-        Runtime.dynCall('viiii', GLUT.mouseFunc, [event['button'], 0/*GLUT_DOWN*/, Browser.mouseX, Browser.mouseY]);
+        Module['dynCall_viiii'](GLUT.mouseFunc, event['button'], 0/*GLUT_DOWN*/, Browser.mouseX, Browser.mouseY);
       }
     },
 
@@ -248,7 +248,7 @@ var LibraryGLUT = {
       if (GLUT.mouseFunc) {
         event.preventDefault();
         GLUT.saveModifiers(event);
-        Runtime.dynCall('viiii', GLUT.mouseFunc, [event['button'], 1/*GLUT_UP*/, Browser.mouseX, Browser.mouseY]);
+        Module['dynCall_viiii'](GLUT.mouseFunc, event['button'], 1/*GLUT_UP*/, Browser.mouseX, Browser.mouseY);
       }
     },
 
@@ -269,7 +269,7 @@ var LibraryGLUT = {
       if (GLUT.mouseFunc) {
         event.preventDefault();
         GLUT.saveModifiers(event);
-        Runtime.dynCall('viiii', GLUT.mouseFunc, [button, 0/*GLUT_DOWN*/, Browser.mouseX, Browser.mouseY]);
+        Module['dynCall_viiii'](GLUT.mouseFunc, button, 0/*GLUT_DOWN*/, Browser.mouseX, Browser.mouseY);
       }
     },
 
@@ -289,21 +289,22 @@ var LibraryGLUT = {
         document.removeEventListener('mozfullscreenchange', GLUT.onFullscreenEventChange, true);
         document.removeEventListener('webkitfullscreenchange', GLUT.onFullscreenEventChange, true);
       }
-      Browser.setCanvasSize(width, height);
+      Browser.setCanvasSize(width, height, true); // N.B. GLUT.reshapeFunc is also registered as a canvas resize callback.
+                                                  // Just call it once here.
       /* Can't call _glutReshapeWindow as that requests cancelling fullscreen. */
       if (GLUT.reshapeFunc) {
         // console.log("GLUT.reshapeFunc (from FS): " + width + ", " + height);
-        Runtime.dynCall('vii', GLUT.reshapeFunc, [width, height]);
+        Module['dynCall_vii'](GLUT.reshapeFunc, width, height);
       }
       _glutPostRedisplay();
     },
 
     requestFullscreen: function() {
-      Browser.requestFullscreen(/*lockPointer=*/false, /*resieCanvas=*/false);
+      Browser.requestFullscreen(/*lockPointer=*/false, /*resizeCanvas=*/false);
     },
 
     requestFullScreen: function() {
-      Module.printErr('GLUT.requestFullScreen() is deprecated. Please call GLUT.requestFullscreen instead.');
+      err('GLUT.requestFullScreen() is deprecated. Please call GLUT.requestFullscreen instead.');
       GLUT.requestFullScreen = function() {
         return GLUT.requestFullscreen();
       }
@@ -320,7 +321,7 @@ var LibraryGLUT = {
     },
 
     cancelFullScreen: function() {
-      Module.printErr('GLUT.cancelFullScreen() is deprecated. Please call GLUT.exitFullscreen instead.');
+      err('GLUT.cancelFullScreen() is deprecated. Please call GLUT.exitFullscreen instead.');
       GLUT.cancelFullScreen = function() {
         return GLUT.exitFullscreen();
       }
@@ -363,7 +364,7 @@ var LibraryGLUT = {
 
     Browser.resizeListeners.push(function(width, height) {
       if (GLUT.reshapeFunc) {
-      	Runtime.dynCall('vii', GLUT.reshapeFunc, [width, height]);
+        Module['dynCall_vii'](GLUT.reshapeFunc, width, height);
       }
     });
 
@@ -431,7 +432,7 @@ var LibraryGLUT = {
   glutIdleFunc: function(func) {
     function callback() {
       if (GLUT.idleFunc) {
-        Runtime.dynCall('v', GLUT.idleFunc);
+        Module['dynCall_v'](GLUT.idleFunc);
         Browser.safeSetTimeout(callback, 4); // HTML spec specifies a 4ms minimum delay on the main thread; workers might get more, but we standardize here
       }
     }
@@ -442,7 +443,7 @@ var LibraryGLUT = {
   },
 
   glutTimerFunc: function(msec, func, value) {
-    Browser.safeSetTimeout(function() { Runtime.dynCall('vi', func, [value]); }, msec);
+    Browser.safeSetTimeout(function() { Module['dynCall_vi'](func, value); }, msec);
   },
 
   glutDisplayFunc: function(func) {
@@ -577,9 +578,10 @@ var LibraryGLUT = {
   glutReshapeWindow__deps: ['$GLUT', 'glutPostRedisplay'],
   glutReshapeWindow: function(width, height) {
     GLUT.exitFullscreen();
-    Browser.setCanvasSize(width, height);
+    Browser.setCanvasSize(width, height, true); // N.B. GLUT.reshapeFunc is also registered as a canvas resize callback.
+                                                // Just call it once here.
     if (GLUT.reshapeFunc) {
-      Runtime.dynCall('vii', GLUT.reshapeFunc, [width, height]);
+      Module['dynCall_vii'](GLUT.reshapeFunc, width, height);
     }
     _glutPostRedisplay();
   },
@@ -615,7 +617,7 @@ var LibraryGLUT = {
       Browser.requestAnimationFrame(function() {
         GLUT.requestedAnimationFrame = false;
         Browser.mainLoop.runIter(function() {
-          Runtime.dynCall('v', GLUT.displayFunc);
+          Module['dynCall_v'](GLUT.displayFunc);
         });
       });
     }
